You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@clerezza.apache.org by re...@apache.org on 2015/04/14 15:13:58 UTC

[83/87] [abbrv] clerezza git commit: CLEREZZA-984: introducing content-launcher, porting platform content, some porting related fixes.

http://git-wip-us.apache.org/repos/asf/clerezza/blob/36b8bdf4/platform/content/src/main/java/org/apache/clerezza/platform/content/WebDavUtils.java
----------------------------------------------------------------------
diff --git a/platform/content/src/main/java/org/apache/clerezza/platform/content/collections/CollectionCreator.java b/platform/content/src/main/java/org/apache/clerezza/platform/content/collections/CollectionCreator.java
index 012d917..4a40b04 100644
--- a/platform/content/src/main/java/org/apache/clerezza/platform/content/collections/CollectionCreator.java
+++ b/platform/content/src/main/java/org/apache/clerezza/platform/content/collections/CollectionCreator.java
@@ -21,26 +21,26 @@ package org.apache.clerezza.platform.content.collections;
 
 import java.net.URI;
 import java.net.URISyntaxException;
-import org.apache.clerezza.rdf.core.MGraph;
-import org.apache.clerezza.rdf.core.UriRef;
-import org.apache.clerezza.rdf.core.impl.TripleImpl;
+import org.apache.clerezza.commons.rdf.Graph;
+import org.apache.clerezza.commons.rdf.IRI;
+import org.apache.clerezza.commons.rdf.impl.utils.TripleImpl;
 import org.apache.clerezza.rdf.ontologies.HIERARCHY;
 import org.apache.clerezza.rdf.ontologies.RDF;
 
 /**
- * Creates the collections containing a resource in an underlying MGraph
+ * Creates the collections containing a resource in an underlying Graph
  *
  * @author reto
  */
 public class CollectionCreator {
 
-    private MGraph mGraph;
+    private Graph mGraph;
 
-    public CollectionCreator(MGraph mGraph) {
+    public CollectionCreator(Graph mGraph) {
         this.mGraph = mGraph;
     }
 
-    public void createContainingCollections(UriRef uriRef) {
+    public void createContainingCollections(IRI uriRef) {
         try {
             URI uri = new URI(uriRef.getUnicodeString());
             if (uri.getHost() == null) {
@@ -59,10 +59,10 @@ public class CollectionCreator {
                 }
                 final String unicodeString = uriRef.getUnicodeString();
                 int lastIndexOf = unicodeString.lastIndexOf(section);
-                UriRef parentUriRef = new UriRef(unicodeString.substring(0, lastIndexOf));
-                mGraph.add(new TripleImpl(uriRef, HIERARCHY.parent, parentUriRef));
-                mGraph.add(new TripleImpl(parentUriRef, RDF.type, HIERARCHY.Collection));
-                uriRef = parentUriRef;
+                IRI parentIRI = new IRI(unicodeString.substring(0, lastIndexOf));
+                mGraph.add(new TripleImpl(uriRef, HIERARCHY.parent, parentIRI));
+                mGraph.add(new TripleImpl(parentIRI, RDF.type, HIERARCHY.Collection));
+                uriRef = parentIRI;
 
             }
         } catch (URISyntaxException ex) {

http://git-wip-us.apache.org/repos/asf/clerezza/blob/36b8bdf4/platform/content/src/main/java/org/apache/clerezza/platform/content/genericmetadata/GenericMetaDataGenerator.java
----------------------------------------------------------------------
diff --git a/platform/content/src/main/java/org/apache/clerezza/platform/content/genericmetadata/GenericMetaDataGenerator.java b/platform/content/src/main/java/org/apache/clerezza/platform/content/genericmetadata/GenericMetaDataGenerator.java
index 7881a34..97ba890 100644
--- a/platform/content/src/main/java/org/apache/clerezza/platform/content/genericmetadata/GenericMetaDataGenerator.java
+++ b/platform/content/src/main/java/org/apache/clerezza/platform/content/genericmetadata/GenericMetaDataGenerator.java
@@ -20,12 +20,12 @@ package org.apache.clerezza.platform.content.genericmetadata;
 
 import java.util.Date;
 import javax.ws.rs.core.MediaType;
+import org.apache.clerezza.commons.rdf.Literal;
+import org.apache.clerezza.rdf.core.LiteralFactory;
 import org.apache.felix.scr.annotations.Component;
 import org.apache.felix.scr.annotations.Service;
 import org.apache.clerezza.rdf.utils.GraphNode;
 import org.apache.clerezza.rdf.metadata.MetaDataGenerator;
-import org.apache.clerezza.rdf.core.LiteralFactory;
-import org.apache.clerezza.rdf.core.TypedLiteral;
 import org.apache.clerezza.rdf.ontologies.DCTERMS;
 
 /**
@@ -39,7 +39,7 @@ public class GenericMetaDataGenerator implements MetaDataGenerator {
 
     @Override
     public void generate(GraphNode node, byte[] data, MediaType mediaType) {
-        TypedLiteral dateLiteral = LiteralFactory.getInstance()
+        Literal dateLiteral = LiteralFactory.getInstance()
                     .createTypedLiteral(new Date());
         if(node.getObjects(DCTERMS.dateSubmitted).hasNext()) {
             if(node.getObjects(DCTERMS.modified).hasNext()) {

http://git-wip-us.apache.org/repos/asf/clerezza/blob/36b8bdf4/platform/content/src/main/resources/org/apache/clerezza/platform/content/collection.ssp
----------------------------------------------------------------------
diff --git a/platform/content/src/main/resources/org/apache/clerezza/platform/content/collection.ssp b/platform/content/src/main/resources/org/apache/clerezza/platform/content/collection.ssp
index bca6d6f..7734e31 100644
--- a/platform/content/src/main/resources/org/apache/clerezza/platform/content/collection.ssp
+++ b/platform/content/src/main/resources/org/apache/clerezza/platform/content/collection.ssp
@@ -19,7 +19,7 @@
  *
 */
 
-def hierarchy(s: Any) = new UriRef("http://clerezza.org/2009/09/hierarchy#" + s)
+def hierarchy(s: Any) = new IRI("http://clerezza.org/2009/09/hierarchy#" + s)
 <div id="tx-content">
 	<h3>{res*}</h3>
 	{ifx ((res/hierarchy("parent")).length != 0){

http://git-wip-us.apache.org/repos/asf/clerezza/blob/36b8bdf4/platform/content/src/test/java/org/apache/clerezza/platform/content/collections/CollectionsCreatorTest.java
----------------------------------------------------------------------
diff --git a/platform/content/src/test/java/org/apache/clerezza/platform/content/collections/CollectionsCreatorTest.java b/platform/content/src/test/java/org/apache/clerezza/platform/content/collections/CollectionsCreatorTest.java
index 7e5b242..fa8c72c 100644
--- a/platform/content/src/test/java/org/apache/clerezza/platform/content/collections/CollectionsCreatorTest.java
+++ b/platform/content/src/test/java/org/apache/clerezza/platform/content/collections/CollectionsCreatorTest.java
@@ -20,10 +20,10 @@ package org.apache.clerezza.platform.content.collections;
 
 import org.junit.Assert;
 import org.junit.Test;
-import org.apache.clerezza.rdf.core.MGraph;
-import org.apache.clerezza.rdf.core.UriRef;
-import org.apache.clerezza.rdf.core.impl.SimpleMGraph;
-import org.apache.clerezza.rdf.core.impl.TripleImpl;
+import org.apache.clerezza.commons.rdf.Graph;
+import org.apache.clerezza.commons.rdf.IRI;
+import org.apache.clerezza.commons.rdf.impl.utils.simple.SimpleGraph;
+import org.apache.clerezza.commons.rdf.impl.utils.TripleImpl;
 import org.apache.clerezza.rdf.ontologies.HIERARCHY;
 import org.apache.clerezza.rdf.ontologies.RDF;
 
@@ -33,15 +33,15 @@ import org.apache.clerezza.rdf.ontologies.RDF;
  */
 public class CollectionsCreatorTest{
 
-    private static UriRef root = new UriRef("http://localhost:8282/");
-    private UriRef foo = new UriRef("http://localhost:8282/foo/");
-    private UriRef fooResource = new UriRef("http://localhost:8282/foo/resource");
-    private UriRef fooTest = new UriRef("http://localhost:8282/foo/test/");
-    private UriRef fooTestResource4 = new UriRef("http://localhost:8282/foo/test/resource4");
+    private static IRI root = new IRI("http://localhost:8282/");
+    private IRI foo = new IRI("http://localhost:8282/foo/");
+    private IRI fooResource = new IRI("http://localhost:8282/foo/resource");
+    private IRI fooTest = new IRI("http://localhost:8282/foo/test/");
+    private IRI fooTestResource4 = new IRI("http://localhost:8282/foo/test/resource4");
         
     @Test
     public void listPositionTest() throws Exception {
-        MGraph mGraph = new SimpleMGraph();
+        Graph mGraph = new SimpleGraph();
         CollectionCreator collectionCreator = new CollectionCreator(mGraph);
         collectionCreator.createContainingCollections(fooTestResource4);
         Assert.assertTrue(mGraph.contains(new TripleImpl(fooTest, RDF.type, HIERARCHY.Collection)));

http://git-wip-us.apache.org/repos/asf/clerezza/blob/36b8bdf4/platform/editor/pom.xml
----------------------------------------------------------------------
diff --git a/platform/editor/pom.xml b/platform/editor/pom.xml
index 76cdb57..f3cef60 100644
--- a/platform/editor/pom.xml
+++ b/platform/editor/pom.xml
@@ -18,15 +18,15 @@
  specific language governing permissions and limitations
  under the License.
 
--->
+    -->
 
     <modelVersion>4.0.0</modelVersion>
 
     <parent>
         <groupId>org.apache.clerezza</groupId>
         <artifactId>clerezza</artifactId>
-        <version>0.5</version>
-        <relativePath>../parent</relativePath>
+        <version>7-SNAPSHOT</version>
+        <relativePath />
     </parent>    
     <groupId>org.apache.clerezza</groupId>
     <artifactId>platform.editor</artifactId>
@@ -43,42 +43,42 @@
         <dependency>
             <groupId>org.apache.clerezza</groupId>
             <artifactId>rdf.core</artifactId>
-            <version>0.14</version>
+            <version>1.0.0-SNAPSHOT</version>
         </dependency>
         <dependency>
             <groupId>org.apache.clerezza</groupId>
             <artifactId>platform.typehandlerspace</artifactId>
-            <version>0.9</version>
+            <version>1.0.0-SNAPSHOT</version>
         </dependency>
         <dependency>
             <groupId>org.apache.clerezza</groupId>
             <artifactId>platform.typerendering.scala</artifactId>
-            <version>0.2</version>
+            <version>1.0.0-SNAPSHOT</version>
         </dependency>
         <dependency>
             <groupId>org.apache.clerezza</groupId>
             <artifactId>rdf.utils</artifactId>
-            <version>0.14</version>
+            <version>1.0.0-SNAPSHOT</version>
         </dependency>
         <dependency>
             <groupId>org.apache.clerezza</groupId>
             <artifactId>rdf.ontologies</artifactId>
-            <version>0.12</version>
+            <version>1.0.0-SNAPSHOT</version>
         </dependency>
         <dependency>
             <groupId>org.apache.clerezza</groupId>
             <artifactId>platform.graphprovider.content</artifactId>
-            <version>0.7</version>
+            <version>1.0.0-SNAPSHOT</version>
         </dependency>
         <dependency>
             <groupId>org.apache.clerezza</groupId>
             <artifactId>platform.graphnodeprovider</artifactId>
-            <version>0.2</version>
+            <version>1.0.0-SNAPSHOT</version>
         </dependency>
         <dependency>
             <groupId>org.apache.clerezza</groupId>
             <artifactId>platform.typerendering.seedsnipe</artifactId>
-            <version>0.7</version>
+            <version>1.0.0-SNAPSHOT</version>
         </dependency>
         <dependency>
             <groupId>org.apache.clerezza</groupId>
@@ -103,14 +103,13 @@
         <dependency>
             <groupId>org.apache.felix</groupId>
             <artifactId>org.apache.felix.scr.annotations</artifactId>
-            <version>1.9.6</version>
         </dependency>
         <dependency>
             <groupId>org.apache.clerezza</groupId>
             <artifactId>platform.config</artifactId>
             <version>0.4</version>
         </dependency>
-    <!--    <dependency>
+        <!--    <dependency>
             <groupId>org.apache.clerezza</groupId>
             <artifactId>platform.security</artifactId>
         </dependency> -->
@@ -152,40 +151,39 @@
         </resources>
         <plugins>
             <plugin>
-				<groupId>org.scala-tools</groupId>
-				<artifactId>maven-scala-plugin</artifactId>
-			</plugin>
+                <groupId>org.scala-tools</groupId>
+                <artifactId>maven-scala-plugin</artifactId>
+            </plugin>
+            <plugin>
+                <groupId>org.apache.felix</groupId>
+                <artifactId>maven-bundle-plugin</artifactId>
+          
+                <extensions>true</extensions>
+                <configuration>
+                    <instructions>
+                        <Import-Package>org.osgi.*; version="[1,2)",javax.ws.rs.*; version="[1,3)",
+                            org.apache.stanbol.commons.security.*; version="[0,3)",
+                            !org.apache.felix.scr.annotations.*,*</Import-Package>
+                        <Bundle-SymbolicName>org.apache.clerezza.platform.editor</Bundle-SymbolicName>
+                        <_nodefaultversion />
+                    </instructions>
+                </configuration>
+            </plugin>
             <plugin>
-          <groupId>org.apache.felix</groupId>
-          <artifactId>maven-bundle-plugin</artifactId>
-          <version>2.4.0</version>
-          <extensions>true</extensions>
-          <configuration>
-            <instructions>
-              <Import-Package>org.osgi.*; version="[1,2)",javax.ws.rs.*; version="[1,3)",
-                                            org.apache.stanbol.commons.security.*; version="[0,3)",
-                  !org.apache.felix.scr.annotations.*,*</Import-Package>
-              <Bundle-SymbolicName>org.apache.clerezza.platform.editor</Bundle-SymbolicName>
-              <_nodefaultversion />
-            </instructions>
-          </configuration>
-        </plugin>
-        <plugin>
-          <groupId>org.apache.felix</groupId>
-          <artifactId>maven-scr-plugin</artifactId>
-          <version>1.14.0</version>
-          <executions>
-            <execution>
-              <id>generate-scr-scrdescriptor</id>
-              <goals>
-                <goal>scr</goal>
-              </goals>
-            </execution>
-          </executions>
-          <configuration>
-              <scanClasses>true</scanClasses> 
-          </configuration>
-        </plugin>
+                <groupId>org.apache.felix</groupId>
+                <artifactId>maven-scr-plugin</artifactId>
+                <executions>
+                    <execution>
+                        <id>generate-scr-scrdescriptor</id>
+                        <goals>
+                            <goal>scr</goal>
+                        </goals>
+                    </execution>
+                </executions>
+                <configuration>
+                    <scanClasses>true</scanClasses> 
+                </configuration>
+            </plugin>
         </plugins>
     </build>
 </project>
\ No newline at end of file

http://git-wip-us.apache.org/repos/asf/clerezza/blob/36b8bdf4/platform/editor/src/main/scala/org/apache/clerezza/platform/editor/Manager.scala
----------------------------------------------------------------------
diff --git a/platform/editor/src/main/scala/org/apache/clerezza/platform/editor/Manager.scala b/platform/editor/src/main/scala/org/apache/clerezza/platform/editor/Manager.scala
index e8e6665..befcff7 100644
--- a/platform/editor/src/main/scala/org/apache/clerezza/platform/editor/Manager.scala
+++ b/platform/editor/src/main/scala/org/apache/clerezza/platform/editor/Manager.scala
@@ -24,7 +24,7 @@ import javax.ws.rs.QueryParam;
 import javax.ws.rs.core.Context;
 import javax.ws.rs.core.UriInfo;
 import org.apache.clerezza.platform.graphprovider.content.ContentGraphProvider
-import org.apache.clerezza.rdf.core.Graph
+import org.apache.clerezza.commons.rdf.ImmutableGraph
 import org.apache.felix.scr.annotations.Activate;
 import org.apache.felix.scr.annotations.Component;
 import org.apache.felix.scr.annotations.Deactivate;
@@ -45,7 +45,7 @@ class Manager {
   def sayHello = "Size of content graph: "+cgp.getContentGraph.size
   
   @PUT
-  def putData(graph: Graph) = {
+  def putData(graph: ImmutableGraph) = {
     //TODO implement
     graph
   }

http://git-wip-us.apache.org/repos/asf/clerezza/blob/36b8bdf4/provisioning/launchers/content-launcher/nb-configuration.xml
----------------------------------------------------------------------
diff --git a/provisioning/launchers/content-launcher/nb-configuration.xml b/provisioning/launchers/content-launcher/nb-configuration.xml
new file mode 100644
index 0000000..ec4540c
--- /dev/null
+++ b/provisioning/launchers/content-launcher/nb-configuration.xml
@@ -0,0 +1,18 @@
+<?xml version="1.0" encoding="UTF-8"?>
+<project-shared-configuration>
+    <!--
+This file contains additional configuration written by modules in the NetBeans IDE.
+The configuration is intended to be shared among all the users of project and
+therefore it is assumed to be part of version control checkout.
+Without this configuration present, some functionality in the IDE may be limited or fail altogether.
+-->
+    <properties xmlns="http://www.netbeans.org/ns/maven-properties-data/1">
+        <!--
+Properties that influence various parts of the IDE, especially code formatting and the like. 
+You can copy and paste the single properties, into the pom.xml file and the IDE will pick them up.
+That way multiple projects can share the same settings (useful for formatting rules for example).
+Any value defined here will override the pom.xml file value but is only applicable to the current project.
+-->
+        <netbeans.compile.on.save>none</netbeans.compile.on.save>
+    </properties>
+</project-shared-configuration>

http://git-wip-us.apache.org/repos/asf/clerezza/blob/36b8bdf4/provisioning/launchers/content-launcher/nbactions.xml
----------------------------------------------------------------------
diff --git a/provisioning/launchers/content-launcher/nbactions.xml b/provisioning/launchers/content-launcher/nbactions.xml
new file mode 100644
index 0000000..101fb77
--- /dev/null
+++ b/provisioning/launchers/content-launcher/nbactions.xml
@@ -0,0 +1,50 @@
+<?xml version="1.0" encoding="UTF-8"?>
+<actions>
+  <action>
+    <actionName>run</actionName>
+    <goals>
+      <goal>clean</goal>
+      <goal>package</goal>
+      <goal>antrun:run</goal>
+      <goal>-o</goal>
+    </goals>
+  </action>
+  <action>
+    <actionName>debug</actionName>
+    <goals>
+      <goal>clean</goal>
+      <goal>package</goal>
+      <goal>antrun:run</goal>
+      <goal>-o</goal>
+    </goals>
+    <properties>
+      <vm.args>-Xdebug -Xrunjdwp:transport=dt_socket,server=n,address=${jpda.address}</vm.args>
+      <jpda.listen>true</jpda.listen>
+    </properties>
+  </action>
+  <action>
+    <actionName>profile</actionName>
+    <goals>
+      <goal>clean</goal>
+      <goal>package</goal>
+      <goal>antrun:run</goal>
+      <goal>-o</goal>
+    </goals>
+    <properties>
+      <vm.args>${profiler.args}</vm.args>
+      <!-- XXX <java jvm="${profiler.java}" ...> -->
+      <profiler.action>profile</profiler.action>
+    </properties>
+  </action>
+  <action>
+        <actionName>CUSTOM-resume-debug</actionName>
+        <displayName>Resume Debug</displayName>
+        <goals>
+            <goal>antrun:run</goal>
+        </goals>
+        <properties>
+            <vm.args>-Xdebug -Xrunjdwp:transport=dt_socket,server=n,address=${jpda.address}</vm.args>
+            <jpda.listen>true</jpda.listen>
+        </properties>
+    </action>
+</actions>

http://git-wip-us.apache.org/repos/asf/clerezza/blob/36b8bdf4/provisioning/launchers/content-launcher/pom.xml
----------------------------------------------------------------------
diff --git a/provisioning/launchers/content-launcher/pom.xml b/provisioning/launchers/content-launcher/pom.xml
new file mode 100644
index 0000000..b56cc14
--- /dev/null
+++ b/provisioning/launchers/content-launcher/pom.xml
@@ -0,0 +1,283 @@
+<?xml version="1.0" encoding="UTF-8"?>
+<!--
+   Copyright 2012 Fusepool.eu Project Partners
+
+   Licensed under the Apache License, Version 2.0 (the "License");
+   you may not use this file except in compliance with the License.
+   You may obtain a copy of the License at
+
+       http://www.apache.org/licenses/LICENSE-2.0
+
+   Unless required by applicable law or agreed to in writing, software
+   distributed under the License is distributed on an "AS IS" BASIS,
+   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+   See the License for the specific language governing permissions and
+   limitations under the License.
+-->
+<project xmlns="http://maven.apache.org/POM/4.0.0" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xsi:schemaLocation="http://maven.apache.org/POM/4.0.0 http://maven.apache.org/maven-v4_0_0.xsd">
+    <modelVersion>4.0.0</modelVersion>
+    <parent>
+        <groupId>org.apache.clerezza</groupId>
+        <artifactId>clerezza</artifactId>
+        <version>7-SNAPSHOT</version>
+        <relativePath />
+    </parent>
+    <groupId>org.apache.clerezza.provisioning</groupId>
+    <artifactId>content-launcher</artifactId>
+    <version>1.0.0-SNAPSHOT</version>
+    <packaging>jar</packaging>
+
+    <name>Clerezza - Provisioning - Launchers - Content Launcher</name>
+    <description>Runnable jar using the clerezza partial bundlelists for 
+        accessing and editing data in the content graph.</description>
+
+    <prerequisites>
+      <maven>3.0.2</maven>
+    </prerequisites>
+    
+    <build>
+        <plugins>
+            <plugin>
+                <groupId>org.apache.maven.plugins</groupId>
+                <artifactId>maven-clean-plugin</artifactId>
+                <configuration>
+                    <filesets>
+                        <fileset>
+                            <directory>.</directory>
+                            <includes>
+                                <include>stanbol/**</include>
+                                <include>*.log</include>
+                            </includes>
+                        </fileset>
+                    </filesets>
+                </configuration>
+            </plugin>
+            <plugin>
+                <groupId>org.apache.sling</groupId>
+                <artifactId>maven-launchpad-plugin</artifactId>
+                <executions>
+                    <execution>
+                        <id>prepare-package</id>
+                        <goals>
+                            <goal>prepare-package</goal>
+                        </goals>
+                        <configuration>
+                            <includeDefaultBundles>false</includeDefaultBundles>
+                            <!-- Standalone jar requires an OSGi http service implementation -->
+                            <jarWebSupport>
+                                <groupId>org.apache.felix</groupId>
+                                <artifactId>org.apache.felix.http.jetty</artifactId>
+                                <version>2.2.1</version>
+                            </jarWebSupport>
+                        </configuration>
+                    </execution>
+                </executions>
+            </plugin>
+            <plugin>
+                <groupId>org.apache.maven.plugins</groupId>
+                <artifactId>maven-jar-plugin</artifactId>
+                <configuration>
+                    <archive>
+                        <manifest>
+                            <addClasspath>true</addClasspath>
+                            <mainClass>org.apache.stanbol.launchpad.Main</mainClass>
+                            <addDefaultImplementationEntries>true</addDefaultImplementationEntries>
+                        </manifest>
+                    </archive>
+                </configuration>
+            </plugin>
+            <plugin>
+                <groupId>org.apache.maven.plugins</groupId>
+                <artifactId>maven-shade-plugin</artifactId>
+                <executions>
+                    <execution>
+                        <phase>package</phase>
+                        <goals>
+                            <goal>shade</goal>
+                        </goals>
+                        <configuration>
+                            <artifactSet>
+                                <!-- Use this to in/exclude only specific dependencies -->
+                                <includes>
+                                    <include>org.apache.stanbol:org.apache.stanbol.commons.launchpad</include>
+                                    <include>org.apache.sling:org.apache.sling.launchpad.base</include>
+                                </includes>
+                            </artifactSet>
+                            <!-- transformers>
+                              <transformer implementation="org.apache.maven.plugins.shade.resource.ComponentsXmlResourceTransformer" />
+                            </transformers -->
+                        </configuration>
+                    </execution>
+                </executions>
+            </plugin>
+            <plugin>
+                <groupId>org.apache.rat</groupId>
+                <artifactId>apache-rat-plugin</artifactId>
+                <configuration>
+                    <excludes />
+                </configuration>
+            </plugin>
+        </plugins>
+        <pluginManagement>
+            <plugins>
+                <plugin>
+                    <groupId>org.apache.sling</groupId>
+                    <artifactId>maven-launchpad-plugin</artifactId>
+                    <version>2.2.0</version>
+                    <extensions>true</extensions>
+                </plugin>
+                <!-- generates version number of dependencies suitable for introspection
+                in pax-exam based OSGi lightweight-integration tests -->
+                <plugin>
+                    <groupId>org.apache.servicemix.tooling</groupId>
+                    <artifactId>depends-maven-plugin</artifactId>
+                    <version>1.0</version>
+                    <executions>
+                        <execution>
+                            <id>generate-depends-file</id>
+                            <goals>
+                                <goal>generate-depends-file</goal>
+                            </goals>
+                        </execution>
+                    </executions>
+                </plugin>
+                <plugin>
+                    <groupId>org.apache.maven.plugins</groupId>
+                    <artifactId>maven-antrun-plugin</artifactId>
+                    <version>1.7</version>
+                    <configuration>
+                        <target>
+                            <property name="vm.args" value="" />
+                            <java fork="true" jar="${project.build.directory}/${project.build.finalName}.jar" dir="${project.build.directory}">
+                                <jvmarg line="-Xmx1024m -XX:MaxPermSize=256M ${vm.args}" />
+                            </java>
+                        </target>
+                    </configuration>
+                </plugin>
+            </plugins>
+        </pluginManagement>
+    </build>
+
+
+    <dependencyManagement>
+        <dependencies>
+            <!-- Sling -->
+            <dependency>
+                <groupId>org.apache.sling</groupId>
+                <artifactId>org.apache.sling.launchpad.base</artifactId>
+                <version>2.5.0</version>
+                <classifier>app</classifier>
+            </dependency>
+            <dependency>
+                <groupId>org.apache.sling</groupId>
+                <artifactId>org.apache.sling.launchpad.base</artifactId>
+                <version>2.5.0</version>
+                <classifier>webapp</classifier>
+                <type>war</type>
+            </dependency>
+            <dependency>
+                <groupId>org.apache.sling</groupId>
+                <artifactId>org.apache.sling.launchpad.installer</artifactId>
+                <version>1.2.0</version>
+            </dependency>
+            <dependency>
+                <groupId>org.apache.sling</groupId>
+                <artifactId>org.apache.sling.launchpad.api</artifactId>
+                <version>1.1.0</version>
+            </dependency>
+            <dependency>
+                <groupId>org.apache.sling</groupId>
+                <artifactId>org.apache.sling.installer.api</artifactId>
+                <version>1.0.0</version>
+            </dependency>
+            <dependency>
+                <groupId>org.apache.sling</groupId>
+                <artifactId>org.apache.sling.installer.core</artifactId>
+                <version>3.4.6</version>
+            </dependency>
+
+        </dependencies>
+    </dependencyManagement>
+
+
+    <dependencies>
+        <dependency>
+            <!-- The Apache Stanbol launchpad -->
+            <groupId>org.apache.stanbol</groupId>
+            <artifactId>org.apache.stanbol.commons.launchpad</artifactId>
+            <version>0.12.0</version>
+        </dependency>
+        <dependency>
+            <!-- maven-launchpad-plugin builds on the launchpad.base app -->
+            <groupId>org.apache.sling</groupId>
+            <artifactId>org.apache.sling.launchpad.base</artifactId>
+            <classifier>app</classifier>
+        </dependency>
+    
+        <!-- BundeLists -->
+        <dependency>
+            <groupId>org.apache.clerezza.provisioning</groupId>
+            <artifactId>felixosgi</artifactId>
+            <version>1.0.0-SNAPSHOT</version>
+            <type>partialbundlelist</type>
+        </dependency>
+        <dependency>
+            <groupId>org.apache.clerezza.provisioning</groupId>
+            <artifactId>felixweb</artifactId>
+            <version>0.1</version>
+            <type>partialbundlelist</type>
+        </dependency>
+       <dependency>
+            <groupId>org.apache.clerezza.provisioning</groupId>
+            <artifactId>rdf</artifactId>
+            <version>1.0.0-SNAPSHOT</version>
+            <type>partialbundlelist</type>
+        </dependency>
+		
+        <dependency>
+             <groupId>org.apache.clerezza.provisioning</groupId>
+             <artifactId>rdf.tdb</artifactId>
+             <version>1.0.0-SNAPSHOT</version>
+             <type>partialbundlelist</type>
+         </dependency>
+		 
+        <dependency>
+            <groupId>org.apache.clerezza.provisioning</groupId>
+            <artifactId>platform.graphnodeprovider</artifactId>
+            <version>1.0.0-SNAPSHOT</version>
+            <type>partialbundlelist</type>
+        </dependency>
+      <dependency>
+            <groupId>org.apache.clerezza.provisioning</groupId>
+            <artifactId>jaxrs</artifactId>
+            <version>0.1</version>
+            <type>partialbundlelist</type>
+        </dependency>
+        <dependency>
+            <groupId>org.apache.clerezza.provisioning</groupId>
+            <artifactId>typehandlerspace</artifactId>
+            <version>1.0.0-SNAPSHOT</version>
+            <type>partialbundlelist</type>
+        </dependency>
+        <dependency>
+            <groupId>org.apache.clerezza.provisioning</groupId>
+            <artifactId>typerendering</artifactId>
+            <version>1.0.0-SNAPSHOT</version>
+            <type>partialbundlelist</type>
+        </dependency>
+        <dependency>
+            <groupId>org.apache.clerezza.provisioning</groupId>
+            <artifactId>rdf.web</artifactId>
+            <version>1.0.0-SNAPSHOT</version>
+            <type>partialbundlelist</type>
+        </dependency>
+        <dependency>
+            <groupId>org.apache.clerezza.provisioning</groupId>
+            <artifactId>platform.content</artifactId>
+            <version>1.0.0-SNAPSHOT</version>
+            <type>partialbundlelist</type>
+        </dependency>
+    </dependencies>
+  
+  
+</project>

http://git-wip-us.apache.org/repos/asf/clerezza/blob/36b8bdf4/provisioning/launchers/content-launcher/src/main/bundles/list.xml
----------------------------------------------------------------------
diff --git a/provisioning/launchers/content-launcher/src/main/bundles/list.xml b/provisioning/launchers/content-launcher/src/main/bundles/list.xml
new file mode 100644
index 0000000..1098261
--- /dev/null
+++ b/provisioning/launchers/content-launcher/src/main/bundles/list.xml
@@ -0,0 +1,5 @@
+<?xml version="1.0" encoding="UTF-8"?>
+<bundles>
+    <startLevel level="1">
+    </startLevel>
+</bundles>

http://git-wip-us.apache.org/repos/asf/clerezza/blob/36b8bdf4/provisioning/launchers/content-launcher/src/main/config/note.txt
----------------------------------------------------------------------
diff --git a/provisioning/launchers/content-launcher/src/main/config/note.txt b/provisioning/launchers/content-launcher/src/main/config/note.txt
new file mode 100644
index 0000000..eb01c8c
--- /dev/null
+++ b/provisioning/launchers/content-launcher/src/main/config/note.txt
@@ -0,0 +1 @@
+Sling launchpad plugin requires this directory
\ No newline at end of file

http://git-wip-us.apache.org/repos/asf/clerezza/blob/36b8bdf4/provisioning/launchers/pom.xml
----------------------------------------------------------------------
diff --git a/provisioning/launchers/pom.xml b/provisioning/launchers/pom.xml
index 9d4c120..ac885f9 100644
--- a/provisioning/launchers/pom.xml
+++ b/provisioning/launchers/pom.xml
@@ -45,8 +45,8 @@
     <modules>
         <module>typerendering-launcher</module>
         <module>linked-data-launcher</module>
+        <module>content-launcher</module>
         <module>shell-launcher</module>
         <module>full-launcher</module>
     </modules>
-
 </project>
\ No newline at end of file

http://git-wip-us.apache.org/repos/asf/clerezza/blob/36b8bdf4/provisioning/platform.content/pom.xml
----------------------------------------------------------------------
diff --git a/provisioning/platform.content/pom.xml b/provisioning/platform.content/pom.xml
index 4f416f5..b9c736b 100644
--- a/provisioning/platform.content/pom.xml
+++ b/provisioning/platform.content/pom.xml
@@ -51,7 +51,7 @@
         <dependency>
             <groupId>org.apache.clerezza</groupId>
             <artifactId>platform.content</artifactId>
-            <version>0.14</version>
+            <version>1.0.0-SNAPSHOT</version>
         </dependency>
         <dependency>
             <groupId>org.apache.clerezza</groupId>
@@ -61,7 +61,13 @@
         <dependency>
             <groupId>org.apache.clerezza</groupId>
             <artifactId>platform.content.fsadaptor</artifactId>
-            <version>0.2</version>
+            <version>1.0.0-SNAPSHOT</version>
+        </dependency>
+        <!-- optional -->
+        <dependency>
+            <groupId>org.apache.clerezza</groupId>
+            <artifactId>platform.editor</artifactId>
+            <version>1.0.0-SNAPSHOT</version>
         </dependency>
         <!-- this doesn't strictly belongs to here -->
         <dependency>

http://git-wip-us.apache.org/repos/asf/clerezza/blob/36b8bdf4/provisioning/rdf.web/pom.xml
----------------------------------------------------------------------
diff --git a/provisioning/rdf.web/pom.xml b/provisioning/rdf.web/pom.xml
index 4254294..5a5e819 100644
--- a/provisioning/rdf.web/pom.xml
+++ b/provisioning/rdf.web/pom.xml
@@ -65,9 +65,9 @@
             <version>0.9</version>
         </dependency>
         <dependency>
-            <groupId>org.apache.clerezza.ext</groupId>
-            <artifactId>org.json.simple</artifactId>
-            <version>0.4</version>
+            <groupId>com.googlecode.json-simple</groupId>
+            <artifactId>json-simple</artifactId>
+            <version>1.1.1</version>
         </dependency>
         <dependency>
             <groupId>org.apache.clerezza</groupId>
@@ -77,7 +77,7 @@
         <dependency>
             <groupId>org.apache.clerezza</groupId>
             <artifactId>web.fileserver</artifactId>
-            <version>0.10</version>
+            <version>1.0.0-SNAPSHOT</version>
         </dependency>
     </dependencies>
 

http://git-wip-us.apache.org/repos/asf/clerezza/blob/36b8bdf4/rdf/core/src/main/java/org/apache/clerezza/rdf/core/access/security/TcAccessController.java
----------------------------------------------------------------------
diff --git a/rdf/core/src/main/java/org/apache/clerezza/rdf/core/access/security/TcAccessController.java b/rdf/core/src/main/java/org/apache/clerezza/rdf/core/access/security/TcAccessController.java
index 274b7e5..3f3551f 100644
--- a/rdf/core/src/main/java/org/apache/clerezza/rdf/core/access/security/TcAccessController.java
+++ b/rdf/core/src/main/java/org/apache/clerezza/rdf/core/access/security/TcAccessController.java
@@ -50,7 +50,7 @@ import org.apache.clerezza.commons.rdf.Literal;
  *
  * Clients with a ConfigureTcAcessPermission can set the permissions required to
  * access a Graph. These permissions are stored persistently in an
- * Graph named urn:x-localinstance:/ImmutableGraph-access.ImmutableGraph
+ * Graph named urn:x-localinstance:/graph-access.graph
  *
  * Clients should get an instance from TcManager.getTcAccessController()
  * 
@@ -59,7 +59,7 @@ import org.apache.clerezza.commons.rdf.Literal;
 public abstract class TcAccessController {
 
     private final TcManager tcManager;
-    private final IRI permissionGraphName = new IRI("urn:x-localinstance:/ImmutableGraph-access.ImmutableGraph");
+    private final IRI permissionGraphName = new IRI("urn:x-localinstance:/graph-access.graph");
     //we can't rely on ontology plugin in rdf core
     private String ontologyNamespace = "http://clerezza.apache.org/2010/07/10/graphpermssions#";
     private final IRI readPermissionListProperty = new IRI(ontologyNamespace + "readPermissionList");
@@ -80,7 +80,7 @@ public abstract class TcAccessController {
 
     /**
      *
-     * @param tcManager the tcManager used to locate urn:x-localinstance:/ImmutableGraph-access.ImmutableGraph
+     * @param tcManager the tcManager used to locate urn:x-localinstance:/graph-access.graph
      */
     public TcAccessController() {
         this.tcManager = getTcManager();

http://git-wip-us.apache.org/repos/asf/clerezza/blob/36b8bdf4/rdf/core/src/test/java/org/apache/clerezza/rdf/core/access/SecurityTest.java
----------------------------------------------------------------------
diff --git a/rdf/core/src/test/java/org/apache/clerezza/rdf/core/access/SecurityTest.java b/rdf/core/src/test/java/org/apache/clerezza/rdf/core/access/SecurityTest.java
index bd11974..36d8692 100644
--- a/rdf/core/src/test/java/org/apache/clerezza/rdf/core/access/SecurityTest.java
+++ b/rdf/core/src/test/java/org/apache/clerezza/rdf/core/access/SecurityTest.java
@@ -77,7 +77,7 @@ public class SecurityTest {
                 result.add(new TcPermission("http://example.org/ImmutableGraph/alreadyexists", "readwrite"));
                 result.add(new TcPermission("http://example.org/read/ImmutableGraph", "read"));
                 result.add(new TcPermission("http://example.org/area/allowed/*", "readwrite"));
-                result.add(new TcPermission("urn:x-localinstance:/ImmutableGraph-access.ImmutableGraph", "readwrite"));
+                result.add(new TcPermission("urn:x-localinstance:/graph-access.graph", "readwrite"));
                 //result.add(new AllPermission());
                 result.add(new RuntimePermission("*"));
                 result.add(new ReflectPermission("suppressAccessChecks"));
@@ -136,7 +136,7 @@ public class SecurityTest {
         TcManager.getInstance().getTcAccessController().setRequiredReadPermissionStrings(graphUri,
                 Collections.singletonList("(java.io.FilePermission \"/etc\" \"write\")"));
         //new FilePermission("/etc", "write").toString()));
-        Graph ag = TcManager.getInstance().getGraph(new IRI("urn:x-localinstance:/ImmutableGraph-access.ImmutableGraph"));
+        Graph ag = TcManager.getInstance().getGraph(new IRI("urn:x-localinstance:/graph-access.graph"));
         System.out.print(ag.toString());
         TcManager.getInstance().getMGraph(graphUri);
     }
@@ -147,7 +147,7 @@ public class SecurityTest {
         TcManager.getInstance().getTcAccessController().setRequiredReadPermissionStrings(graphUri,
                 Collections.singletonList("(java.io.FilePermission \"/etc\" \"write\")"));
         //new FilePermission("/etc", "write").toString()));
-        Graph ag = TcManager.getInstance().getGraph(new IRI("urn:x-localinstance:/ImmutableGraph-access.ImmutableGraph"));
+        Graph ag = TcManager.getInstance().getGraph(new IRI("urn:x-localinstance:/graph-access.graph"));
         System.out.print(ag.toString());
         TcManager.getInstance().createGraph(graphUri);
     }
@@ -158,7 +158,7 @@ public class SecurityTest {
         TcManager.getInstance().getTcAccessController().setRequiredReadWritePermissionStrings(graphUri,
                 Collections.singletonList("(java.io.FilePermission \"/etc\" \"write\")"));
         //new FilePermission("/etc", "write").toString()));
-        Graph ag = TcManager.getInstance().getGraph(new IRI("urn:x-localinstance:/ImmutableGraph-access.ImmutableGraph"));
+        Graph ag = TcManager.getInstance().getGraph(new IRI("urn:x-localinstance:/graph-access.graph"));
         System.out.print(ag.toString());
         TcManager.getInstance().createGraph(graphUri);
     }

http://git-wip-us.apache.org/repos/asf/clerezza/blob/36b8bdf4/rdf/file.storage/pom.xml
----------------------------------------------------------------------
diff --git a/rdf/file.storage/pom.xml b/rdf/file.storage/pom.xml
index 4932a7c..e6aebe4 100644
--- a/rdf/file.storage/pom.xml
+++ b/rdf/file.storage/pom.xml
@@ -33,6 +33,14 @@
     <version>1.0.0-SNAPSHOT</version>
     <name>Clerezza - RDF File Storage Provider</name>
     <description>A file base storage provider</description>
+    <build>
+        <plugins>
+            <plugin>
+                <groupId>org.apache.felix</groupId>
+                <artifactId>maven-scr-plugin</artifactId>
+            </plugin> 
+        </plugins>
+    </build>
     <dependencies>
         <dependency>
             <groupId>junit</groupId>

http://git-wip-us.apache.org/repos/asf/clerezza/blob/36b8bdf4/rdf/file.storage/src/main/java/org/apache/clerezza/rdf/file/storage/FileTcProvider.java
----------------------------------------------------------------------
diff --git a/rdf/file.storage/src/main/java/org/apache/clerezza/rdf/file/storage/FileTcProvider.java b/rdf/file.storage/src/main/java/org/apache/clerezza/rdf/file/storage/FileTcProvider.java
index 1382189..ec457c1 100644
--- a/rdf/file.storage/src/main/java/org/apache/clerezza/rdf/file/storage/FileTcProvider.java
+++ b/rdf/file.storage/src/main/java/org/apache/clerezza/rdf/file/storage/FileTcProvider.java
@@ -42,6 +42,9 @@ import org.apache.clerezza.rdf.core.access.NoSuchEntityException;
 import org.apache.clerezza.rdf.core.access.WeightedTcProvider;
 import org.apache.clerezza.rdf.core.serializedform.Parser;
 import org.apache.clerezza.rdf.core.serializedform.Serializer;
+import org.apache.felix.scr.annotations.Component;
+import org.apache.felix.scr.annotations.Property;
+import org.apache.felix.scr.annotations.Service;
 
 /**
  * The <code>FileTcProvider</code> is a <code>WeightedTcProvider</code> that
@@ -57,12 +60,11 @@ import org.apache.clerezza.rdf.core.serializedform.Serializer;
  * availability of these services.
  * The default weight of the provider is 300.
  *
- * @scr.component
- * @scr.service interface="org.apache.clerezza.rdf.core.access.WeightedTcProvider"
- * @scr.property name="weight" type="Integer" value="300"
- * 
  * @author mir
  */
+@Component
+@Service(WeightedTcProvider.class)
+@Property(name = "weight", intValue = 300)
 public class FileTcProvider implements WeightedTcProvider {
 
     /**

http://git-wip-us.apache.org/repos/asf/clerezza/blob/36b8bdf4/web.fileserver/pom.xml
----------------------------------------------------------------------
diff --git a/web.fileserver/pom.xml b/web.fileserver/pom.xml
index ae63ac1..87e4a75 100644
--- a/web.fileserver/pom.xml
+++ b/web.fileserver/pom.xml
@@ -24,8 +24,8 @@
     <parent>
         <groupId>org.apache.clerezza</groupId>
         <artifactId>clerezza</artifactId>
-        <version>0.5</version>
-        <relativePath>../parent</relativePath>
+        <version>7-SNAPSHOT</version>
+        <relativePath />
     </parent>
     <groupId>org.apache.clerezza</groupId>
     <artifactId>web.fileserver</artifactId>
diff --git a/platform/content/src/main/java/org/apache/clerezza/platform/content/WebDavUtils.java b/platform/content/src/main/java/org/apache/clerezza/platform/content/WebDavUtils.java
index aea5190..19f094d 100644
--- a/platform/content/src/main/java/org/apache/clerezza/platform/content/WebDavUtils.java
+++ b/platform/content/src/main/java/org/apache/clerezza/platform/content/WebDavUtils.java
@@ -41,13 +41,13 @@ import javax.xml.transform.TransformerException;
 import javax.xml.transform.TransformerFactory;
 import javax.xml.transform.TransformerFactoryConfigurationError;
 import javax.xml.transform.dom.DOMResult;
-import org.apache.clerezza.rdf.core.Literal;
+import org.apache.clerezza.commons.rdf.Literal;
+import org.apache.clerezza.commons.rdf.RDFTerm;
+import org.apache.clerezza.commons.rdf.Triple;
+import org.apache.clerezza.commons.rdf.Graph;
+import org.apache.clerezza.commons.rdf.IRI;
+import org.apache.clerezza.commons.rdf.impl.utils.TripleImpl;
 import org.apache.clerezza.rdf.core.LiteralFactory;
-import org.apache.clerezza.rdf.core.Resource;
-import org.apache.clerezza.rdf.core.Triple;
-import org.apache.clerezza.rdf.core.TripleCollection;
-import org.apache.clerezza.rdf.core.UriRef;
-import org.apache.clerezza.rdf.core.impl.TripleImpl;
 import org.apache.clerezza.rdf.ontologies.DCTERMS;
 import org.apache.clerezza.rdf.ontologies.HIERARCHY;
 import org.apache.clerezza.rdf.ontologies.RDF;
@@ -203,16 +203,16 @@ class WebDavUtils {
      * Putting the properties in a DOM Document *
      *------------------------------------------*/
 
-    static Document createResponseDoc(Map<UriRef, PropertyMap> resultMap)
+    static Document createResponseDoc(Map<IRI, PropertyMap> resultMap)
             throws ParserConfigurationException {
         Document responseDoc = DocumentBuilderFactory.newInstance().
                 newDocumentBuilder().newDocument();
-        Set<UriRef> nodeNameSet = resultMap.keySet();
+        Set<IRI> nodeNameSet = resultMap.keySet();
 
         Element multistatElement = responseDoc.createElementNS(davUri,"D:" + multistat);
         // add multistat element to response
         responseDoc.appendChild(multistatElement);
-        for (UriRef nodeName : nodeNameSet) {
+        for (IRI nodeName : nodeNameSet) {
             Element responseElement = responseDoc.createElementNS(davUri, "D:" + response);
             // add response element to response Document
             multistatElement.appendChild(responseElement);
@@ -223,7 +223,7 @@ class WebDavUtils {
     }
 
     private static void addElementsToResponse(PropertyMap propertyMap,
-            Element responseElement, Document responseDoc, UriRef nodeName) {
+            Element responseElement, Document responseDoc, IRI nodeName) {
         Element hrefElement = responseDoc.createElementNS(davUri, "D:" + href);
         hrefElement.setTextContent(nodeName.getUnicodeString());
         // add hrefElement element to responseElement
@@ -282,7 +282,7 @@ class WebDavUtils {
      * Get the properties from the CollectionNode and its members *
      *------------------------------------------------------------*/
 
-    static Map<UriRef, PropertyMap> getPropsByName(NodeList children,
+    static Map<IRI, PropertyMap> getPropsByName(NodeList children,
             GraphNode node, String depthHeader, boolean includeValues) {
         List<Property> requestedUserProps = new ArrayList<Property>();
         List<Property> requestedDavProps = new ArrayList<Property>();
@@ -300,7 +300,7 @@ class WebDavUtils {
                 requestedUserProps.add(new Property(nsUri, localName));
             }
         }
-        Map<UriRef, PropertyMap> allprops = new HashMap<UriRef, PropertyMap>();
+        Map<IRI, PropertyMap> allprops = new HashMap<IRI, PropertyMap>();
 
         if (node.hasProperty(RDF.type, HIERARCHY.Collection)) {
             return getCollectionProps(allprops, requestedUserProps, requestedDavProps,
@@ -313,11 +313,11 @@ class WebDavUtils {
 
     }
     
-    static Map<UriRef, PropertyMap> getCollectionProps(Map<UriRef, PropertyMap> allprops,
+    static Map<IRI, PropertyMap> getCollectionProps(Map<IRI, PropertyMap> allprops,
             List<Property> requestedUserProps, List<Property> requestedDavProps,
             GraphNode collection, String depthHeader, boolean includeValues) {
         if(allprops == null){
-            allprops = new HashMap<UriRef, PropertyMap>();
+            allprops = new HashMap<IRI, PropertyMap>();
         }
         addNodeProperties(allprops, requestedUserProps, requestedDavProps, collection,
                 includeValues);
@@ -333,7 +333,7 @@ class WebDavUtils {
         return allprops;
     }
 
-    private static void addMemberProps(Map<UriRef, PropertyMap> allprops,
+    private static void addMemberProps(Map<IRI, PropertyMap> allprops,
             List<Property> requestedUserProps, List<Property> requestedDavProps,
             List<GraphNode> members, String depthHeader, boolean includeValues) {
         for (GraphNode member : members) {
@@ -347,7 +347,7 @@ class WebDavUtils {
         }
     }
 
-    static void addNodeProperties(Map<UriRef, PropertyMap> allprops,
+    static void addNodeProperties(Map<IRI, PropertyMap> allprops,
             List<Property> requestedUserProps, List<Property> requestedDavProps,
             GraphNode node,    boolean includeValues) {
 
@@ -365,13 +365,13 @@ class WebDavUtils {
             addDavPropsWithoutValues(propertyMap);
             addUserPropsWithoutValues(node, propertyMap);
         }
-        allprops.put((UriRef) node.getNode(), propertyMap);
+        allprops.put((IRI) node.getNode(), propertyMap);
 
     }
 
     private static void addUserProps(GraphNode node, PropertyMap propertyMap,
             List<Property> requestedProps) {
-        Iterator<UriRef> userPropsIter;
+        Iterator<IRI> userPropsIter;
         Lock readLock = node.readLock();
         readLock.lock(); 
         try {
@@ -379,18 +379,18 @@ class WebDavUtils {
         } finally {
             readLock.unlock();
         }
-        Set<UriRef> userProps = new HashSet<UriRef>();
+        Set<IRI> userProps = new HashSet<IRI>();
         while (userPropsIter.hasNext()) {
             userProps.add(userPropsIter.next());
         }
         userProps.remove(HIERARCHY.members);
         if (requestedProps != null) {
             for (Property requestedProp : requestedProps) {
-                UriRef predicate = new UriRef(requestedProp.value());
+                IRI predicate = new IRI(requestedProp.value());
                 if (userProps.contains(predicate)) {
                     readLock.lock();
                     try {
-                        Iterator<Resource> value = node.getObjects(predicate);
+                        Iterator<RDFTerm> value = node.getObjects(predicate);
                         if (value.hasNext()) {
                             propertyMap.put(requestedProp, getValue(value.next()));
                         } else {
@@ -404,7 +404,7 @@ class WebDavUtils {
                 }
             }
         } else {
-            for (UriRef uri : userProps) {
+            for (IRI uri : userProps) {
                 String userProp = uri.getUnicodeString();
                 int index = userProp.lastIndexOf("#");
                 if (index == -1) {
@@ -413,7 +413,7 @@ class WebDavUtils {
                 Property property = new Property(userProp.substring(0, index + 1),
                         userProp.substring(index + 1));
 
-                Iterator<Resource> value = node.getObjects(uri);
+                Iterator<RDFTerm> value = node.getObjects(uri);
                 readLock.lock();
                 try {
                     if (value.hasNext()) {
@@ -430,7 +430,7 @@ class WebDavUtils {
 
     private static void addUserPropsWithoutValues(GraphNode node,
             PropertyMap propertyMap) {
-        Iterator<UriRef> userPropsIter;
+        Iterator<IRI> userPropsIter;
         Lock readLock = node.readLock();
         readLock.lock();
         try {
@@ -438,12 +438,12 @@ class WebDavUtils {
         } finally {
             readLock.unlock();
         }
-        Set<UriRef> userProps = new HashSet<UriRef>();
+        Set<IRI> userProps = new HashSet<IRI>();
         while (userPropsIter.hasNext()) {
             userProps.add(userPropsIter.next());
         }
         userProps.remove(HIERARCHY.members);
-        for (UriRef uri : userProps) {
+        for (IRI uri : userProps) {
             String userProp = uri.getUnicodeString();
             int index = userProp.lastIndexOf("#");
             if (index == -1) {
@@ -457,12 +457,12 @@ class WebDavUtils {
 
     /**
      * @param resource
      * @return returns the unicode string of an UriRef or the lexical form of a
      * Literal or the return value of a toString() on a BNode
      */
-    private static String getValue(Resource resource){
-        if(resource instanceof UriRef){
-            return ((UriRef)resource).getUnicodeString();
+    private static String getValue(RDFTerm resource){
+        if(resource instanceof IRI){
+            return ((IRI)resource).getUnicodeString();
         }else if(resource instanceof Literal){
             return ((Literal)resource).getLexicalForm();
         }else {
@@ -482,7 +482,7 @@ class WebDavUtils {
         for (Property property : requestedProps) {
             if (davProps.contains(property.prop)) {
                 if (property.prop.equalsIgnoreCase(displayname)) {
-                    propertyMap.put(property, getLastSection(((UriRef)node.getNode()).getUnicodeString()));
+                    propertyMap.put(property, getLastSection(((IRI)node.getNode()).getUnicodeString()));
                 } else if (property.prop.equalsIgnoreCase(resourcetype)) {
                     if (node.hasProperty(RDF.type, HIERARCHY.Collection)) {
                         propertyMap.put(property, "collection");
@@ -493,7 +493,7 @@ class WebDavUtils {
                     Lock readLock = node.readLock();
                     readLock.lock();
                     try {
-                        Iterator<Resource> date = node.getObjects(DCTERMS.dateSubmitted);
+                        Iterator<RDFTerm> date = node.getObjects(DCTERMS.dateSubmitted);
                         if (date.hasNext()) {
                             String st = getValue(date.next());
                             propertyMap.put(property, st);
@@ -507,7 +507,7 @@ class WebDavUtils {
                     Lock readLock = node.readLock();
                     readLock.lock();
                     try {
-                        Iterator<Resource> date = node.getObjects(DCTERMS.modified);
+                        Iterator<RDFTerm> date = node.getObjects(DCTERMS.modified);
                         if (date.hasNext()) {
                             String st = getValue(date.next());
                             propertyMap.put(property, st);
@@ -521,7 +521,7 @@ class WebDavUtils {
                     Lock readLock = node.readLock();
                     readLock.lock();
                     try {
-                        Iterator<Resource> mediaType = node.getObjects(DCTERMS.MediaType);
+                        Iterator<RDFTerm> mediaType = node.getObjects(DCTERMS.MediaType);
                         if (mediaType.hasNext()) {
                             String st = getValue(mediaType.next());
                             propertyMap.put(property, st);
@@ -554,7 +554,7 @@ class WebDavUtils {
             NodeList propsToRemove) throws ParserConfigurationException {
         Document responseDoc = DocumentBuilderFactory.newInstance()
                     .newDocumentBuilder().newDocument();
-        UriRef subject = (UriRef) hierarchyNode.getNode();
+        IRI subject = (IRI) hierarchyNode.getNode();
         Element hrefElement = responseDoc.createElementNS(davUri, href);
         hrefElement.setTextContent(subject.getUnicodeString());
         Element multistatus = responseDoc.createElementNS(davUri, multistat);
@@ -568,7 +568,7 @@ class WebDavUtils {
 
         Map<Property, String> setMap = getNodeListAsMap(propsToSet);
         Map<Property, String> removeMap = getNodeListAsMap(propsToRemove);
-        TripleCollection contentGraph = hierarchyNode.getGraph();
+        Graph contentGraph = hierarchyNode.getGraph();
         for(Map.Entry<Property, String> entry : setMap.entrySet()){
             Property property = entry.getKey();
             if(property.ns.equalsIgnoreCase(davUri)){
@@ -576,11 +576,11 @@ class WebDavUtils {
                     propForbidden.appendChild(responseDoc
                             .createElementNS(davUri, property.prop));
                 } else {
-                    UriRef predicate = new UriRef(property.value());
+                    IRI predicate = new IRI(property.value());
                     Lock writeLock = hierarchyNode.writeLock();
                     writeLock.lock();
                     try {
-                        Iterator<Resource> valIter = hierarchyNode.getObjects(predicate);
+                        Iterator<RDFTerm> valIter = hierarchyNode.getObjects(predicate);
                         replaceProp(subject, predicate, valIter, contentGraph, entry);
                     } finally {
                         writeLock.unlock();
@@ -588,11 +588,11 @@ class WebDavUtils {
                     propOk.appendChild(responseDoc.createElementNS(davUri, property.prop));
                 }
             } else {
-                UriRef predicate = new UriRef(property.value());
+                IRI predicate = new IRI(property.value());
                 Lock writeLock = hierarchyNode.writeLock();
                 writeLock.lock();
                 try {
-                    Iterator<Resource> valIter = hierarchyNode.getObjects(predicate);
+                    Iterator<RDFTerm> valIter = hierarchyNode.getObjects(predicate);
                     replaceProp(subject, predicate, valIter, contentGraph, entry);
                 } finally {
                     writeLock.unlock();
@@ -607,11 +607,11 @@ class WebDavUtils {
                 propForbidden.appendChild(responseDoc
                             .createElementNS(davUri, property.prop));
             } else {
-                UriRef predicate = new UriRef(property.value());
+                IRI predicate = new IRI(property.value());
                 Lock writeLock = hierarchyNode.writeLock();
                 writeLock.lock();
                 try {
-                    Iterator<Resource> valIter = hierarchyNode.getObjects(predicate);
+                    Iterator<RDFTerm> valIter = hierarchyNode.getObjects(predicate);
                     Set<Triple> triplesToBeRemoved = new HashSet<Triple>();
                     while (valIter.hasNext()) {
                         triplesToBeRemoved.add(new TripleImpl(subject, predicate, valIter.next()));
@@ -661,8 +661,8 @@ class WebDavUtils {
         return result;
     }
 
-    private static void replaceProp(UriRef subject, UriRef predicate,
-            Iterator<Resource> valIter, TripleCollection contentGraph,
+    private static void replaceProp(IRI subject, IRI predicate,
+            Iterator<RDFTerm> valIter, Graph contentGraph,
             Map.Entry<Property, String> entry) {
         LiteralFactory fac = LiteralFactory.getInstance();
         Set<Triple> triplesToBeRemoved = new HashSet<Triple>();

http://git-wip-us.apache.org/repos/asf/clerezza/blob/36b8bdf4/platform/content/src/main/java/org/apache/clerezza/platform/content/collections/CollectionCreator.java
----------------------------------------------------------------------
@@ -457,12 +457,12 @@ class WebDavUtils {
     /**
      * @param resource
-     * @return returns the unicode string of an UriRef or the lexical form of a
-     * Literal or the return value of a toString() on a BNode
+     * @return returns the unicode string of an IRI or the lexical form of a
+     * Literal or the return value of a toString() on a BlankNode
      */